pub struct Jump { /* private fields */ }Implementations
Sourceimpl Jump
impl Jump
Sourcepub fn new(map: Beatmap) -> Self
pub fn new(map: Beatmap) -> Self
Creates a new jump analyzer for the given beatmap.
Arguments
map- The beatmap to analyze, type: rosu_map::Beatmap.
Sourcepub fn analyze(&mut self) -> JumpAnalysis
pub fn analyze(&mut self) -> JumpAnalysis
Analyzes the beatmap for jumps and returns a JumpAnalysis.
Example
let path = Path::new("example-maps/jump-caffeinefighter.osu");
let map = rosu_map::from_path::<rosu_map::Beatmap>(path).unwrap();
let mut jump_analyzer = Jump::new(map);
let analasis = jump_analyzer.analyze();
println!("{:#?}", analasis);Auto Trait Implementations
impl Freeze for Jump
impl RefUnwindSafe for Jump
impl Send for Jump
impl Sync for Jump
impl Unpin for Jump
impl UnwindSafe for Jump