pub struct Stream { /* private fields */ }Implementations
Sourceimpl Stream
impl Stream
Sourcepub fn new(map: Beatmap) -> Self
pub fn new(map: Beatmap) -> Self
Creates a new stream analyzer for the given beatmap.
Arguments
map- The beatmap to analyze, type: rosu_map::Beatmap.
Sourcepub fn analyze(&mut self) -> StreamAnalysis
pub fn analyze(&mut self) -> StreamAnalysis
Analyzes the beatmap for streams and returns a StreamAnalysis.
Example
let path = Path::new("example-maps/jump-caffeinefighter.osu");
let map = rosu_map::from_path::<rosu_map::Beatmap>(path).unwrap();
let mut stream_analyzer = Stream::new(map);
let analasis = stream_analyzer.analyze();
println!("{:#?}", analasis);Auto Trait Implementations
impl Freeze for Stream
impl RefUnwindSafe for Stream
impl Send for Stream
impl Sync for Stream
impl Unpin for Stream
impl UnwindSafe for Stream